@@ -35,15 +35,13 @@ test_that("OptimizerAsyncMbo works with evaluations in archive", {
   optimizer = opt("async_random_search")
   optimizer$optimize(instance)
 
-
   instance$terminator$param_set$values$n_evals = 40L
 
   optimizer = opt("async_mbo")
-  optimizer$optimize(instance)
 
-  instance$archive
-  expect_data_table(instance$archive$data[is.na(get("acq_cb"))], min.rows = 10)
-  expect_data_table(instance$archive$data[!is.na(get("acq_cb"))], min.rows = 20)
+  expect_data_table(optimizer$optimize(instance), nrows = 1L)
+  expect_data_table(instance$archive$data[is.na(get("acq_cb"))], min.rows = 10L)
+  expect_data_table(instance$archive$data[!is.na(get("acq_cb"))], min.rows = 20L)
 
   expect_rush_reset(instance$rush)
 })
